@@ -1,14 +1,15 @@
-/*  $Revision: 1.5 $
+/*  $Revision: 1.1.1.1 $
 **
 **  Produce reliable locks for shell scripts, by Peter Honeyman as told
 **  to Rich $alz.
 */
-#include "configdata.h"
 #include <stdio.h>
+#include <sys/types.h>
+#include "configdata.h"
+#include "clibrary.h"
 #include <errno.h>
 #include <fcntl.h>
-#include <sys/types.h>
-#include "clibrary.h"
+#include <sys/stat.h>
 
 
 STATIC BOOL	BinaryLock;
@@ -27,13 +28,14 @@ ValidLock(name, JustChecking)
 {
     register int	fd;
     register int	i;
-    int			pid;
+    PID_T		pid;
     char		buff[BUFSIZ];
 
     /* Open the file. */
     if ((fd = open(name, O_RDONLY)) < 0) {
-	if (!JustChecking)
-	    (void)fprintf(stderr, CANTOPEN, name, strerror(errno));
+	if (JustChecking)
+	    return FALSE;
+	(void)fprintf(stderr, CANTOPEN, name, strerror(errno));
 	return TRUE;
     }
 
@@ -50,14 +52,14 @@ ValidLock(name, JustChecking)
 	    return FALSE;
 	}
 	buff[i] = '\0';
-	pid = atoi(buff);
+	pid = (PID_T) atol(buff);
     }
     (void)close(fd);
     if (pid <= 0)
 	return FALSE;
 
     /* Send the signal. */
-    if (kill((PID_T)pid, 0) < 0 && errno == ESRCH)
+    if (kill(pid, 0) < 0 && errno == ESRCH)
 	return FALSE;
 
     /* Either the kill worked, or we're optimistic about the error code. */
@@ -102,7 +104,7 @@ main(ac, av)
     char		tmp[BUFSIZ];
     char		buff[BUFSIZ];
     char		*name;
-    int			pid;
+    PID_T		pid;
     BOOL		ok;
     BOOL		JustChecking;
 
@@ -110,6 +112,7 @@ main(ac, av)
     pid = 0;
     name = NULL;
     JustChecking = FALSE;
+    (void)umask(NEWSUMASK);
 
     /* Parse JCL. */
     while ((i = getopt(ac, av, "bcup:f:")) != EOF)
@@ -125,7 +128,7 @@ main(ac, av)
 	    JustChecking = TRUE;
 	    break;
 	case 'p':
-	    pid = atoi(optarg);
+	    pid = (PID_T) atol(optarg);
 	    break;
 	case 'f':
 	    name = optarg;
@@ -163,9 +166,9 @@ main(ac, av)
 
     /* Write the process ID. */
     if (BinaryLock)
-	ok = write(fd, (POINTER)pid, (SIZE_T)sizeof pid) == sizeof pid;
+	ok = write(fd, (POINTER)&pid, (SIZE_T)sizeof pid) == sizeof pid;
     else {
-	(void)sprintf(buff, "%d\n", pid);
+	(void)sprintf(buff, "%ld\n", (long) pid);
 	i = strlen(buff);
 	ok = write(fd, (POINTER)buff, (SIZE_T)i) == i;
     }
