@@ -1,4 +1,4 @@
-/*  $Revision: 1.12 $
+/*  $Revision: 1.12.2.1 $
 **
 ** Provide a command line interface to the storage manager
 */
@@ -26,6 +26,7 @@ int main(int argc, char **argv) {
     BOOL                Overview = FALSE;
     BOOL                Rawformat = FALSE;
     BOOL		val;
+    BOOL		notinitialized = TRUE;
     int                 i;
     char                *p;
     QIOSTATE            *qp;
@@ -91,11 +92,6 @@ int main(int argc, char **argv) {
 		exit(1);
 	    }
 	}
-	if (!SMinit()) {
-	    if (!Quiet)
-		fprintf(stderr, "Could not initialize the storage manager: %s", SMerrorstr);
-	    exit(1);
-	}
     }
     
     for (i = optind; i < argc; i++) {
@@ -105,6 +101,14 @@ int main(int argc, char **argv) {
 		    fprintf(stderr, "%s is not a storage token\n", argv[i]);
 		continue;
 	    }
+	    if (notinitialized) {
+		if (!SMinit()) {
+		    if (!Quiet)
+			fprintf(stderr, "Could not initialize the storage manager: %s", SMerrorstr);
+		    exit(1);
+		}
+		notinitialized = FALSE;
+	    }
 	    if (!SMcancel(TextToToken(argv[i]))) {
 		if (!Quiet)
 		    fprintf(stderr, "Could not remove %s: %s\n", argv[i], SMerrorstr);
@@ -115,6 +119,14 @@ int main(int argc, char **argv) {
 		    fprintf(stderr, "%s is not a storage token\n", argv[i]);
 		continue;
 	    }
+	    if (notinitialized) {
+		if (!SMinit()) {
+		    if (!Quiet)
+			fprintf(stderr, "Could not initialize the storage manager: %s", SMerrorstr);
+		    exit(1);
+		}
+		notinitialized = FALSE;
+	    }
 	    token = TextToToken(argv[i]);
 	    if ((p = OVERretrieve(&token, &linelen)) == (char *)NULL) {
 		if (!Quiet)
@@ -135,6 +147,14 @@ int main(int argc, char **argv) {
 		    continue;
 		}
 		token = TextToToken(argv[i]);
+		if (notinitialized) {
+		    if (!SMinit()) {
+			if (!Quiet)
+			     fprintf(stderr, "Could not initialize the storage manager: %s", SMerrorstr);
+			exit(1);
+		    }
+		    notinitialized = FALSE;
+		}
 		if ((art = SMretrieve(token, RETR_ALL)) == NULL) {
 		    if (!Quiet)
 			fprintf(stderr, "Could not retrieve %s\n", argv[i]);
@@ -147,6 +167,16 @@ int main(int argc, char **argv) {
 		}
 		SMfreearticle(art);
 	    } else {
+		if (IsToken(argv[i])) {
+		    if (notinitialized) {
+			if (!SMinit()) {
+			    if (!Quiet)
+				fprintf(stderr, "Could not initialize the storage manager: %s", SMerrorstr);
+			    exit(1);
+			}
+			notinitialized = FALSE;
+		    }
+		}
 		if ((qp = QIOopen(argv[i])) == NULL) {
 		    if (!Quiet)
 			fprintf(stderr, "Could not open %s\n", argv[i]);
