@@ -1,15 +1,20 @@
-/*  $Revision: 1.11 $
+/*  $Id: lc.c,v 1.7 1998/06/03 07:22:06 kondou Exp $
 **
 **  Routines for the local connect channel.  Create a Unix-domain stream
 **  socket that processes on the local server connect to.  Once the
 **  connection is set up, we speak NNTP.  The connect channel is used only
 **  by rnews to feed in articles from the UUCP sites.
 */
+#include <stdio.h>
+#include <sys/types.h>
+#include <netinet/in.h>
+#include "configdata.h"
+#include "clibrary.h"
 #include "innd.h"
-#if	defined(DO_HAVE_UNIX_DOMAIN)
+#if	defined(HAVE_UNIX_DOMAIN_SOCKETS)
 #include <sys/un.h>
 
-STATIC char	LCpath[] = _PATH_NNTPCONNECT;
+STATIC char	*LCpath = NULL;
 STATIC CHANNEL	*LCchan;
 
 
@@ -29,13 +34,13 @@ LCreader(cp)
 	return;
     }
 
-    if ((fd = accept(cp->fd, (struct sockaddr *)NULL, (int *)NULL)) < 0) {
+    if ((fd = accept(cp->fd, (struct sockaddr *)NULL, (ARGTYPE *)NULL)) < 0) {
 	syslog(L_ERROR, "%s cant accept CCreader %m", LogName);
 	return;
     }
-    new = NCcreate(fd, FALSE);
+    new = NCcreate(fd, FALSE, TRUE);
     new->Address.s_addr = MyAddress.s_addr;
-    syslog(L_NOTICE, "%s connected %d", "local", new->fd);
+    syslog(L_NOTICE, "%s connected %d", "localhost", new->fd);
 }
 
 
@@ -47,7 +52,7 @@ LCwritedone()
 {
     syslog(L_ERROR, "%s internal LCwritedone", LogName);
 }
-#endif	/* defined(DO_HAVE_UNIX_DOMAIN) */
+#endif	/* defined(HAVE_UNIX_DOMAIN_SOCKETS) */
 
 
 /*
@@ -56,10 +61,12 @@ LCwritedone()
 void
 LCsetup()
 {
-#if	defined(DO_HAVE_UNIX_DOMAIN)
+#if	defined(HAVE_UNIX_DOMAIN_SOCKETS)
     int			i;
     struct sockaddr_un	server;
 
+    if (LCpath == NULL)
+	LCpath = COPY(cpcatpath(innconf->pathrun, _PATH_NNTPCONNECT));
     /* Remove old detritus. */
     if (unlink(LCpath) < 0 && errno != ENOENT) {
 	syslog(L_FATAL, "%s cant unlink %s %m", LogName, LCpath);
@@ -87,7 +94,7 @@ LCsetup()
     LCchan = CHANcreate(i, CTlocalconn, CSwaiting, LCreader, LCwritedone);
     syslog(L_NOTICE, "%s lcsetup %s", LogName, CHANname(LCchan));
     RCHANadd(LCchan);
-#endif	/* defined(DO_HAVE_UNIX_DOMAIN) */
+#endif	/* defined(HAVE_UNIX_DOMAIN_SOCKETS) */
 }
 
 
@@ -97,10 +104,10 @@ LCsetup()
 void
 LCclose()
 {
-#if	defined(DO_HAVE_UNIX_DOMAIN)
+#if	defined(HAVE_UNIX_DOMAIN_SOCKETS)
     CHANclose(LCchan, CHANname(LCchan));
     LCchan = NULL;
     if (unlink(LCpath) < 0)
 	syslog(L_ERROR, "%s cant unlink %s %m", LogName, LCpath);
-#endif	/* defined(DO_HAVE_UNIX_DOMAIN) */
+#endif	/* defined(HAVE_UNIX_DOMAIN_SOCKETS) */
 }
