@@ -1,4 +1,4 @@
-/*  $Id: rc.c,v 1.31.2.3 1999/01/27 15:27:29 kondou Exp $
+/*  $Id: rc.c,v 1.31.2.4 1999/09/13 11:08:50 kondou Exp $
 **
 **  Routines for the remote connect channel.  Create an Internet stream socket
 **  that processes connect to.  If the incoming site is not one of our feeds,
@@ -1221,7 +1221,7 @@ RCwritelist(char *filename)
         if (*p == '/')
 	   q = p + 1;
 
-    fprintf (F, "##  $Revision: 1.31.2.3 $\n");
+    fprintf (F, "##  $Revision: 1.31.2.4 $\n");
     fprintf (F, "##  %s - names and addresses that feed us news\n", q);
     DISPOSE(r);
     fprintf (F, "##\n\n");
@@ -1342,6 +1342,19 @@ RChostname(cp)
     return buff;
 }
 
+/*
+**  Find the label name of a remote host we've connected to.
+*/
+char *
+RClabelname(CHANNEL *cp) {
+    REMOTEHOST	*rp;
+    int		i;
+
+    for (rp = RCpeerlist, i = RCnpeerlist; --i >= 0; rp++)
+	if (cp->Address.s_addr == rp->Address.s_addr)
+	    return rp->Label;
+    return NULL;
+}
 
 /*
 **  Is the remote site allowed to post to this group?
