@@ -4,7 +4,7 @@
  * Start Date:  Sun Dec 31 18:52:04 1995
  * Project:     INN (innfeed)
  * File:        tape.c
- * RCSId:       $Id: tape.c,v 1.9 1998/05/21 10:14:58 kondou Exp $
+ * RCSId:       $Id: tape.c,v 1.10 1998/06/19 11:58:18 scrappy Exp $
  *
  * Copyright:   Copyright (c) 1996 by Internet Software Consortium
  *
@@ -40,7 +40,7 @@
 
  
 #if ! defined (lint)
-static const char *rcsid = "$Id: tape.c,v 1.9 1998/05/21 10:14:58 kondou Exp $" ;
+static const char *rcsid = "$Id: tape.c,v 1.10 1998/06/19 11:58:18 scrappy Exp $" ;
 static void use_rcsid (const char *rid) {   /* Never called */
   use_rcsid (rcsid) ; use_rcsid (rid) ;
 }
@@ -785,6 +785,17 @@ Article getArticle (Tape tape)
                 filename = NULL ; /* line only had one field */
             }
 
+          /* See if message ID looks valid. */
+          if (msgid) {
+            for (p = msgid; *p; p++)
+              ;
+            if (p > msgid) p--;
+            if (*msgid != '<' || *p != '>') {
+              syslog (LOG_ERR,TAPE_SPAGHETTI,tape->inputFilename,msgid);
+              msgid = NULL;
+            }
+          }
+
           if (filename != NULL && msgid != NULL)
             art = newArticle (filename, msgid) ;
 
