@@ -1,11 +1,11 @@
-/*  $Revision: 1.2 $
+/*  $Revision: 1.2.4.1 $
 **
 */
 #include <stdio.h>
 #include <sys/types.h>
 #include "configdata.h"
 #include "clibrary.h"
-#include "patchlevel.h"
+#include "innversion.h"
 
     /* Length of string plus trailing space. */
 #define S(x)	sizeof(x)
