@@ -1,4 +1,4 @@
-/*  $Revision: 1.9.2.3 $
+/*  $Revision: 1.9.2.4 $
 **
 **  The newnews command.
 */
@@ -376,7 +376,7 @@ CMDnewnews(int ac, char *av[])
 		msgid[p2-q] = '\0';
 		Printf("%s\r\n", msgid);
 	    } else {
-		*(--p) = '\0';
+		*p = '\0';
 		Printf("%s\r\n", line);
 	    }
 	} while (fgets(line, sizeof line, F) != NULL);
