@@ -1,7 +1,11 @@
-/*  $Revision: 1.9 $
+/*  $Revision: 1.2 $
 **  This file has been modified to get it to compile more easily
 **  on pre-4.4BSD (e.g., SysVr4 :-) systems.  Rich $alz, June 1991.
 */
+#include <stdio.h>
+#include <sys/types.h>
+#include "configdata.h"
+#include "clibrary.h"
 
     /* change these three if you must keep running an old syslog. */
 #define	_PATH_LOGFILE	"/dev/log"
@@ -21,14 +25,11 @@
     /* if you need various BSD functions, set  this. */
 #define NEED_BZERO_ETC
 
-    /* Use "union wait" instead of int? */
-    /* =()<#define @<USE_UNION_WAIT>@_USE_UNION_WAIT>()= */
-#define DO_USE_UNION_WAIT
-#if	defined(DO_USE_UNION_WAIT)
+#if	defined(HAVE_UNION_WAIT)
 #define WAITVALUE	union wait
 #else
 #define WAITVALUE	int
-#endif	/* defined(DO_USE_UNION_WAIT) */
+#endif	/* defined(HAVE_UNION_WAIT) */
 
 /*
  * Copyright (c) 1983, 1988 Regents of the University of California.
@@ -91,14 +92,17 @@ static char sccsid[] = "@(#)syslogd.c	5.42 (Berkeley) 6/29/90";
 #include <sys/errno.h>
 #include <sys/ioctl.h>
 #include <sys/stat.h>
-#include <sys/wait.h>
+#ifdef HAVE_WAIT_H
+# include <wait.h>
+#else
+# include <sys/wait.h>
+#endif
 #include <sys/socket.h>
 #include <sys/file.h>
 #include <sys/uio.h>
 #include <sys/un.h>
 #include <sys/time.h>
 #include <sys/resource.h>
-#include <sys/signal.h>
 
 #ifdef	MSG_BSIZE
 #undef	MSG_BSIZE
@@ -109,17 +113,24 @@ static char sccsid[] = "@(#)syslogd.c	5.42 (Berkeley) 6/29/90";
 #include <netdb.h>
 
 #include <utmp.h>
-#include <stdio.h>
 #include <ctype.h>
 #include <string.h>
 
 #define SYSLOG_NAMES
 #include "syslog.h"
 
+#ifndef UT_NAMESIZE
 #define UT_NAMESIZE	8
+#endif
+#ifndef _PATH_UTMP
 #define	_PATH_UTMP	"/etc/utmp"
+#endif
+#ifndef _PATH_DEV
 #define	_PATH_DEV	"/dev/"
+#endif
+#ifndef _PATH_CONSOLE
 #define	_PATH_CONSOLE	"/dev/console"
+#endif
 
 #ifndef sigmask
 #define sigmask(m)      (1 << ((m)-1))
@@ -137,6 +148,7 @@ char	ctty[] = _PATH_CONSOLE;
 
 #ifdef NEED_BZERO_ETC
 #include <fcntl.h>
+void
 bzero(b, length)
     char *b;
     int length;
@@ -144,6 +156,7 @@ bzero(b, length)
     while (--length >= 0)
 	*b++ = '\0';
 }
+void
 bcopy(b1, b2, length)
     char *b1;
     char *b2;
@@ -157,6 +170,7 @@ setlinebuf(f)
 {
     setbuf(f, (char *)NULL);
 }
+PID_T
 wait3(status, flags, np)
     WAITVALUE *status;
     int flags;
@@ -264,7 +278,8 @@ int	MarkInterval = 20 * 60;	/* interval between marks in seconds */
 int	MarkSeq = 0;		/* mark sequence number */
 
 extern	int errno;
-extern	char *ctime(), *strchr(), *malloc();
+extern	char *ctime(), *strchr();
+extern  POINTER malloc();
 SIGHANDLER die(), domark(), init(), reapchild();
 
 int
@@ -387,7 +402,7 @@ main(argc, argv)
 	/* tuck my process id away */
 	fp = fopen(PidFile, "w");
 	if (fp != NULL) {
-		fprintf(fp, "%d\n", getpid());
+		fprintf(fp, "%ld\n", (long) getpid());
 		(void) fclose(fp);
 	}
 
@@ -1260,7 +1275,7 @@ decode(name, codetab)
 daemon(nochdir, noclose)
         int nochdir, noclose;
 {
-        int cpid;
+        PID_T cpid;
 
         if ((cpid = fork()) == -1)
                 return (-1);
@@ -1342,7 +1357,8 @@ ttymsg(iov, iovcnt, line)
 			continue;
 		}
 		if (errno == EWOULDBLOCK) {
-			int cpid, off = 0;
+			PID_T cpid;
+			int off = 0;
 
 			if (forked) {
 				(void) close(fd);
